{%- from "ceph/map.jinja" import common with context %}

{%- set ceph_cluster = common.get('cluster_name', 'ceph') %}
{% if not common.get('container_mode', False) %}

common_packages:
  pkg.installed:
  - names: {{ common.pkgs }}

/etc/default/ceph:
  file.managed:
  - source: salt://ceph/files/env
  - template: jinja
  - require:
    - pkg: common_packages

{%- endif %}

{{ common.prefix_dir }}/etc/ceph:
  file.directory:
  - user: ceph
  - group: ceph
  - mode: 755
  - makedirs: True

common_config:
  file.managed:
  - name: {{ common.prefix_dir }}/etc/ceph/{{ ceph_cluster }}.conf
  - user: ceph
  - group: ceph
  - source: salt://ceph/files/{{ common.version }}/ceph.conf.{{ grains.os_family }}
  - template: jinja
  {% if not common.get('container_mode', False) %}
  - require:
    - pkg: common_packages
  {%- endif %}

{%- if common.keyring is defined and common.keyring.admin is defined and common.keyring.admin.caps is defined %}
  {%- set managed_keyring_path = common.get('keyring', {}).get('admin', {}).get('path', common.prefix_dir + '/etc/ceph/' + ceph_cluster + '.client.admin.keyring') %}

  {%- if common.get("manage_admin_keyring", False) %}
    {%- set admin_cmd = '--add-key ' + common.keyring.admin.key %}
  {%- else %}
    {%- set admin_cmd = '--gen-key' %}
  {%- endif %}

ceph_create_keyring_admin:
  cmd.run:
  - name: "ceph-authtool --create-keyring {{ managed_keyring_path }} {{ admin_cmd }} -n client.admin {%- for cap_name, cap in common.keyring.admin.caps.iteritems() %} --cap {{ cap_name }} '{{ cap }}' {%- endfor %}"
  - unless: "test -f {{ managed_keyring_path }}"
  - require:
  {% if not common.get('container_mode', False) %}
    - pkg: common_packages
  {%- endif %}
    - file: common_config

{%- endif %}

{# Pick first element from grains, check if it has ceph_keyring for current cluster and this keyring belongs to 'admin' #}
{%- for node_name, node_grains in salt['mine.get']('ceph:common:keyring:admin', 'grains.items', 'pillar').iteritems() %}
  {%- if loop.index0 == 0 %}
    {%- if node_grains.ceph is defined and node_grains.ceph.get('fsid', '') == common.fsid %}
      {%- for keyring_name, keyring_obj in node_grains.ceph.get('ceph_keyring', {}).iteritems() %}
        {%- if keyring_name == 'admin' %}
          {%- set keyring_path = keyring_obj.get('path', common.prefix_dir + '/etc/ceph/' + ceph_cluster + '.client.admin.keyring') %}

grains_admin_keyring_manage:
  file.managed:
  - name: {{ keyring_path }}
  - source: salt://ceph/files/keyring
  - template: jinja
  - unless: "test -f {{ keyring_path }}"
  - defaults:
      node_grains: {{ node_grains|yaml }}
      keyring: {{ keyring_obj|yaml }}
      name: {{ keyring_name }}
  - require:
  {% if not common.get('container_mode', False) %}
    - pkg: common_packages
  {%- endif %}
    - file: common_config

        {%- endif %}
      {%- endfor %}
    {%- endif %}
  {%- endif %}
{%- endfor %}
